@@ -6,8 +6,6 @@
 
 use crate::prelude::*;
 
-def_subcontrol!(Form, uiForm);
+def_subcontrol!(ty: Form, handle: uiForm,);
 
-impl Form {
-
-}
+impl Form<'_> {}
