@@ -6,14 +6,23 @@
 
 use crate::prelude::*;
 
-impl Ui {
+impl<'ui> Ui<'ui> {
     /// Creates a new [`Image`].
-    pub fn create_image(&self, width: f64, height: f64) -> Result<&mut Image, crate::Error> {
-        call_libui_new_fn!(self, Image, uiNewImage, width, height)
+    pub fn create_image<'a>(
+        &'a self,
+        width: f64,
+        height: f64,
+    ) -> Result<&'a mut Image<'ui>, crate::Error> {
+        call_libui_new_fn!(
+            ui: self,
+            ui_lt: 'ui,
+            alloc: alloc_image,
+            fn: uiNewImage(width, height) -> Image,
+        )
     }
 }
 
-def_subcontrol!(Image, uiImage);
+def_subcontrol!(ty: Image, handle: uiImage,);
 
 #[repr(C)]
 pub struct Pixel {
@@ -23,8 +32,8 @@ pub struct Pixel {
     pub a: u8,
 }
 
-impl Image {
-    pub fn append(&mut self, pixels: &mut [Pixel], width: u16, height: u16, byte_stride: u16) {
+impl Image<'_> {
+    pub fn append(&self, pixels: &mut [Pixel], width: u16, height: u16, byte_stride: u16) {
         unsafe {
             uiImageAppend(
                 self.as_ptr(),
