@@ -9,29 +9,35 @@ pub mod item;
 pub use item::Item;
 
 use crate::prelude::*;
+use std::marker::PhantomData;
 
-impl Ui {
+impl<'ui> Ui<'ui> {
     /// Creates a new [`Menu`].
-    pub fn create_menu(&self, name: impl AsRef<str>) -> Result<&mut Menu, crate::Error> {
+    pub fn create_menu<'a>(
+        &'a self,
+        name: impl AsRef<str>,
+    ) -> Result<&'a mut Menu<'ui>, crate::Error> {
         let name = make_cstring!(name.as_ref());
-        call_fallible_libui_fn!(
-            uiNewMenu,
-            name.as_ptr(),
-        )
-        .map(|menu| {
-            self.alloc_object(Menu(menu))
+        call_fallible_libui_fn!(uiNewMenu(name.as_ptr())).map(|menu| {
+            self.alloc_menu(Menu::<'ui> {
+                ptr: menu,
+                _ui: PhantomData,
+            })
         })
     }
 }
 
-pub struct Menu(*mut uiMenu);
+pub struct Menu<'ui> {
+    ptr: *mut uiMenu,
+    _ui: PhantomData<&'ui Ui<'ui>>,
+}
 
-impl Menu {
+impl Menu<'_> {
     pub fn as_ptr(&self) -> *mut uiMenu {
-        self.0
+        self.ptr
     }
 
-    pub fn append_separator(&mut self) {
+    pub fn append_separator(&self) {
         unsafe { uiMenuAppendSeparator(self.as_ptr()) };
     }
 }
